# piwwwaterflow
Flask/Gunicorn Webservice for piwaterflow system

+ 1.1.0
  + Avoid service caching by adding timestamp to URL
+ 1.1.1
  + Point to new grafana 
+ 1.2.2
  + New waterflow config & LAN influxdb
+ 1.2.3
  + Black header & config fix
